==> haskell-yesod-default-1.2.0-546-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-6NKgLqPdIyq2shVEoa6seo
key: yesod-default-1.2.0-6NKgLqPdIyq2shVEoa6seo
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: 559487fd1bbb1f19fb078938daa41d7d
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-6NKgLqPdIyq2shVEoa6seo
depends:
    base-4.12.0.0 yesod-core-1.6.14-4EV6A63mwW3Jj03mhiCKrD
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-547-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-G94vlibbfJL5mnuyXxwxFA
key: yesod-default-1.2.0-G94vlibbfJL5mnuyXxwxFA
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: 028e77eec3f0cb35c75ea79887d2d377
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-G94vlibbfJL5mnuyXxwxFA
depends:
    base-4.12.0.0 yesod-core-1.6.14-EuRsuwX5KCIHFIhzqQhAqC
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
